@@ -28,7 +28,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-commands.h 6819 2009-01-07 14:56:55Z icq $
+ * $Id: gedit-commands.h 6912 2009-02-22 17:00:21Z pborelli $
  */
 
 #ifndef __GEDIT_COMMANDS_H__
@@ -54,14 +54,10 @@ gint		 gedit_commands_load_uris		(GeditWindow         *window,
 /*
  * Non-exported functions
  */
- 
-gint		_gedit_cmd_load_files			(GeditWindow         *window,
-							 const GSList        *uris,
-							 const GeditEncoding *encoding);
-							 
+
 /* Create titled documens for non-existing URIs */
 gint		_gedit_cmd_load_files_from_prompt	(GeditWindow         *window,
-							 const GSList        *uris,
+							 GSList              *files,
 							 const GeditEncoding *encoding,
 							 gint                 line_pos);
 
