@@ -26,7 +26,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-plugin-manager.c 6406 2008-08-13 20:04:04Z pborelli $
+ * $Id: gedit-plugin-manager.c 6851 2009-01-16 12:04:06Z icq $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -109,6 +109,7 @@ about_button_cb (GtkWidget          *button,
 		"comments", gedit_plugin_info_get_description (info),
 		"website", gedit_plugin_info_get_website (info),
 		"logo-icon-name", gedit_plugin_info_get_icon_name (info),
+		"version", gedit_plugin_info_get_version (info),
 		NULL);
 
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (pm->priv->about),
@@ -645,7 +646,10 @@ plugin_manager_construct_tree (GeditPluginManager *pm)
 
 	gedit_debug (DEBUG_PLUGINS);
 
-	model = gtk_list_store_new (N_COLUMNS, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, GEDIT_TYPE_PLUGIN_INFO);
+	model = gtk_list_store_new (N_COLUMNS,
+				    G_TYPE_BOOLEAN,
+				    G_TYPE_BOOLEAN,
+				    G_TYPE_POINTER);
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (pm->priv->tree),
 				 GTK_TREE_MODEL (model));
@@ -788,6 +792,11 @@ gedit_plugin_manager_init (GeditPluginManager *pm)
 
 	pm->priv = GEDIT_PLUGIN_MANAGER_GET_PRIVATE (pm);
 
+	/*
+	 * Always we create the manager, firstly we rescan the plugins directory
+	 */
+	gedit_plugins_engine_rescan_plugins (gedit_plugins_engine_get_default ());
+
 	gtk_box_set_spacing (GTK_BOX (pm), 6);
 
 	label = gtk_label_new (NULL);
