@@ -92,7 +92,7 @@ gedit_print_preview_get_property (GObject    *object,
 				  GValue     *value,
 				  GParamSpec *pspec)
 {
-	GeditPrintPreview *preview = GEDIT_PRINT_PREVIEW (object);
+	//GeditPrintPreview *preview = GEDIT_PRINT_PREVIEW (object);
 	
 	switch (prop_id)
 	{
@@ -108,7 +108,7 @@ gedit_print_preview_set_property (GObject      *object,
 				  const GValue *value,
 				  GParamSpec   *pspec)
 {
-	GeditPrintPreview *preview = GEDIT_PRINT_PREVIEW (object);
+	//GeditPrintPreview *preview = GEDIT_PRINT_PREVIEW (object);
 	
 	switch (prop_id)
 	{
@@ -121,7 +121,7 @@ gedit_print_preview_set_property (GObject      *object,
 static void
 gedit_print_preview_finalize (GObject *object)
 {
-	GeditPrintPreview *preview = GEDIT_PRINT_PREVIEW (object);
+	//GeditPrintPreview *preview = GEDIT_PRINT_PREVIEW (object);
 
 	G_OBJECT_CLASS (gedit_print_preview_parent_class)->finalize (object);
 }
@@ -558,9 +558,7 @@ create_bar (GeditPrintPreview *preview)
 	gtk_tool_button_set_label (GTK_TOOL_BUTTON (priv->prev),
 				   "P_revious Page");
 	gtk_tool_button_set_use_underline (GTK_TOOL_BUTTON (priv->prev), TRUE);
-	gtk_tool_item_set_tooltip (priv->prev,
-				   GTK_TOOLBAR (toolbar)->tooltips,
-				   _("Show the previous page"), "");
+	gtk_tool_item_set_tooltip_text (priv->prev, _("Show the previous page"));
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), priv->prev, -1);
 	g_signal_connect (priv->prev,
 			  "clicked",
@@ -572,9 +570,7 @@ create_bar (GeditPrintPreview *preview)
 	gtk_tool_button_set_label (GTK_TOOL_BUTTON (priv->next),
 				   "_Next Page");
 	gtk_tool_button_set_use_underline (GTK_TOOL_BUTTON (priv->next), TRUE);
-	gtk_tool_item_set_tooltip (priv->next,
-				   GTK_TOOLBAR (toolbar)->tooltips,
-				   _("Show the next page"), "");
+	gtk_tool_item_set_tooltip_text (priv->next, _("Show the next page"));
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), priv->next, -1);
 	g_signal_connect (priv->next,
 			  "clicked",
@@ -590,8 +586,7 @@ create_bar (GeditPrintPreview *preview)
 	priv->page_entry = gtk_entry_new ();
 	gtk_entry_set_width_chars (GTK_ENTRY (priv->page_entry), 3);
 	gtk_entry_set_max_length (GTK_ENTRY (priv->page_entry), 6);
-	gtk_widget_set_tooltip_text (priv->page_entry,
-				     _("Current page (Alt+P)"));
+	gtk_widget_set_tooltip_text (priv->page_entry, _("Current page (Alt+P)"));
 
 	g_signal_connect (priv->page_entry,
 			  "activate", 
@@ -639,9 +634,7 @@ create_bar (GeditPrintPreview *preview)
 	gtk_tool_button_set_label (GTK_TOOL_BUTTON (priv->multi),
 				   "_Show Multiple Pages");
 	gtk_tool_button_set_use_underline (GTK_TOOL_BUTTON (priv->multi), TRUE);
-	gtk_tool_item_set_tooltip (priv->multi,
-				   GTK_TOOLBAR (toolbar)->tooltips,
-				   _("Show multiple pages"), "");
+	gtk_tool_item_set_tooltip_text (priv->multi, _("Show multiple pages"));
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), priv->multi, -1);
 	g_signal_connect (priv->multi,
 			  "clicked",
@@ -654,9 +647,7 @@ create_bar (GeditPrintPreview *preview)
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), i, -1);
 
 	priv->zoom_one = gtk_tool_button_new_from_stock (GTK_STOCK_ZOOM_100);
-	gtk_tool_item_set_tooltip (priv->zoom_one,
-				   GTK_TOOLBAR (toolbar)->tooltips,
-				   _("Zoom 1:1"), "");
+	gtk_tool_item_set_tooltip_text (priv->zoom_one, _("Zoom 1:1"));
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), priv->zoom_one, -1);
 	g_signal_connect (priv->zoom_one,
 			  "clicked",
@@ -665,9 +656,7 @@ create_bar (GeditPrintPreview *preview)
 	gtk_widget_show (GTK_WIDGET (priv->zoom_one));
 
 	priv->zoom_fit = gtk_tool_button_new_from_stock (GTK_STOCK_ZOOM_FIT);
-	gtk_tool_item_set_tooltip (priv->zoom_fit,
-				   GTK_TOOLBAR (toolbar)->tooltips,
-				   _("Zoom to fit the whole page"), "");
+	gtk_tool_item_set_tooltip_text (priv->zoom_fit,	_("Zoom to fit the whole page"));
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), priv->zoom_fit, -1);
 	g_signal_connect (priv->zoom_fit,
 			  "clicked",
@@ -676,9 +665,7 @@ create_bar (GeditPrintPreview *preview)
 	gtk_widget_show (GTK_WIDGET (priv->zoom_fit));
 
 	priv->zoom_in = gtk_tool_button_new_from_stock (GTK_STOCK_ZOOM_IN);
-	gtk_tool_item_set_tooltip (priv->zoom_in,
-				   GTK_TOOLBAR (toolbar)->tooltips,
-				   _("Zoom the page in"), "");
+	gtk_tool_item_set_tooltip_text (priv->zoom_in, _("Zoom the page in"));
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), priv->zoom_in, -1);
 	g_signal_connect (priv->zoom_in,
 			  "clicked",
@@ -687,9 +674,7 @@ create_bar (GeditPrintPreview *preview)
 	gtk_widget_show (GTK_WIDGET (priv->zoom_in));
 
 	priv->zoom_out = gtk_tool_button_new_from_stock (GTK_STOCK_ZOOM_OUT);
-	gtk_tool_item_set_tooltip (priv->zoom_out,
-				   GTK_TOOLBAR (toolbar)->tooltips,
-				   _("Zoom the page out"), "");
+	gtk_tool_item_set_tooltip_text (priv->zoom_out, _("Zoom the page out"));
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), priv->zoom_out, -1);
 	g_signal_connect (priv->zoom_out,
 			  "clicked",
@@ -704,8 +689,7 @@ create_bar (GeditPrintPreview *preview)
 	i = gtk_tool_button_new (NULL, _("_Close Preview"));
 	gtk_tool_button_set_use_underline (GTK_TOOL_BUTTON (i), TRUE);
 	gtk_tool_item_set_is_important (i, TRUE);
-	gtk_tool_item_set_tooltip (i, GTK_TOOLBAR (toolbar)->tooltips, 
-				   _("Close print preview"), "");
+	gtk_tool_item_set_tooltip_text (i, _("Close print preview"));
 	g_signal_connect (i, "clicked",
 			  G_CALLBACK (close_button_clicked), preview);
 	gtk_widget_show (GTK_WIDGET (i));
@@ -784,25 +768,35 @@ preview_layout_key_press (GtkWidget         *widget,
 			  GeditPrintPreview *preview)
 {
 	GeditPrintPreviewPrivate *priv;
+	GtkAdjustment *hadj, *vadj;
 	double x, y;
 	guint h, w;
-	double lower, upper;
-	double page_size;
+	double hlower, hupper, vlower, vupper;
+	double hpage, vpage;
 	double hstep, vstep;
 	gboolean domove = FALSE;
 	gboolean ret = TRUE;
 
 	priv = preview->priv;
 
-	x = gtk_layout_get_hadjustment (GTK_LAYOUT (priv->layout))->value;
-	y = gtk_layout_get_vadjustment (GTK_LAYOUT (priv->layout))->value;
-	gtk_layout_get_size (GTK_LAYOUT (priv->layout), &w, &h);
+	hadj = gtk_layout_get_hadjustment (GTK_LAYOUT (priv->layout));
+	vadj = gtk_layout_get_vadjustment (GTK_LAYOUT (priv->layout));
 
-	g_object_get (gtk_layout_get_vadjustment (GTK_LAYOUT (priv->layout)),
-		      "lower", &lower,
-		      "upper", &upper,
-		      "page-size", &page_size,
+	x = hadj->value;
+	y = vadj->value;
+
+	g_object_get (hadj,
+		      "lower", &hlower,
+		      "upper", &hupper,
+		      "page-size", &hpage,
 		      NULL);
+	g_object_get (vadj,
+		      "lower", &vlower,
+		      "upper", &vupper,
+		      "page-size", &vpage,
+		      NULL);
+
+	gtk_layout_get_size (GTK_LAYOUT (priv->layout), &w, &h);
 
 	hstep = 10;
 	vstep = 10;
@@ -824,31 +818,31 @@ preview_layout_key_press (GtkWidget         *widget,
 	case GDK_KP_Right:
 	case GDK_Right:
 		if (event->state & GDK_SHIFT_MASK)
-			x += w;
+			x = hupper - hpage;
 		else
-			x += hstep;
+			x = MIN (hupper - hpage, x + hstep);
 		domove = TRUE;
 		break;
 	case GDK_KP_Left:
 	case GDK_Left:
 		if (event->state & GDK_SHIFT_MASK)
-			x -= w;
+			x = hlower;
 		else
-			x -= hstep;
+			x = MAX (hlower, x - hstep);
 		domove = TRUE;
 		break;
 	case GDK_KP_Up:
 	case GDK_Up:
 		if (event->state & GDK_SHIFT_MASK)
 			goto page_up;
-		y -= vstep;
+		y = MAX (vlower, y - vstep);
 		domove = TRUE;
 		break;
 	case GDK_KP_Down:
 	case GDK_Down:
 		if (event->state & GDK_SHIFT_MASK)
 			goto page_down;
-		y += vstep;
+		y = MIN (vupper - vpage, y + vstep);
 		domove = TRUE;
 		break;
 	case GDK_KP_Page_Up:
@@ -857,17 +851,17 @@ preview_layout_key_press (GtkWidget         *widget,
 	case GDK_KP_Delete:
 	case GDK_BackSpace:
 	page_up:
-		if (y <= lower)
+		if (y <= vlower)
 		{
 			if (preview->priv->cur_page > 0)
 			{
 				goto_page (preview, preview->priv->cur_page - 1);
-				y = (upper - page_size);
+				y = (vupper - vpage);
 			}
 		}
 		else
 		{
-			y = lower;
+			y = vlower;
 		}
 		domove = TRUE;
 		break;
@@ -875,17 +869,17 @@ preview_layout_key_press (GtkWidget         *widget,
 	case GDK_Page_Down:
 	case ' ':
 	page_down:
-		if (y >= (upper - page_size))
+		if (y >= (vupper - vpage))
 		{
 			if (preview->priv->cur_page < preview->priv->n_pages - 1)
 			{
 				goto_page (preview, preview->priv->cur_page + 1);
-				y = lower;
+				y = vlower;
 			}
 		}
 		else
 		{
-			y = (upper - page_size);
+			y = (vupper - vpage);
 		}
 		domove = TRUE;
 		break;
@@ -923,11 +917,6 @@ preview_layout_key_press (GtkWidget         *widget,
 
 	if (domove)
 	{
-		GtkAdjustment *hadj, *vadj;
-
-		hadj = gtk_layout_get_hadjustment (GTK_LAYOUT (priv->layout));
-		vadj = gtk_layout_get_vadjustment (GTK_LAYOUT (priv->layout));
-
 		gtk_adjustment_set_value (hadj, x);
 		gtk_adjustment_set_value (vadj, y);
 
