@@ -25,14 +25,14 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-taglist-plugin-parser.h 4429 2005-12-12 17:28:04Z pborelli $
+ * $Id: gedit-taglist-plugin-parser.h 6745 2008-12-28 21:27:48Z icq $
  */
 
 #ifndef __GEDIT_TAGLIST_PLUGIN_PARSER_H__
 #define __GEDIT_TAGLIST_PLUGIN_PARSER_H__
 
 #include <libxml/tree.h>
-#include <glib/glist.h>
+#include <glib.h>
 
 typedef struct _TagList TagList;
 typedef struct _TagGroup TagGroup;
@@ -60,7 +60,7 @@ struct _Tag
 /* Note that the taglist is ref counted */
 extern TagList *taglist;
 
-TagList* create_taglist (void);
+TagList* create_taglist (const gchar *data_dir);
 
 void free_taglist (void);
 
